@@ -41,6 +41,9 @@ FAILEDOPERATION_CDBINSTANCELOCKFAILERROR = 'FailedOperation.CdbInstanceLockFailE
 # Creation failed. Please check whether the user already exists.
 FAILEDOPERATION_CREATEACCOUNTERROR = 'FailedOperation.CreateAccountError'
 
+# Failed to create the audit rule.
+FAILEDOPERATION_CREATEAUDITFAILERROR = 'FailedOperation.CreateAuditFailError'
+
 # Failed to assign an exclusive VIP to the read-only replica.
 FAILEDOPERATION_CREATEROVIPERROR = 'FailedOperation.CreateRoVipError'
 
@@ -80,12 +83,21 @@ FAILEDOPERATION_STATUSCONFLICT = 'FailedOperation.StatusConflict'
 # Failed to submit the task. Please try again later. If the submission remains unsuccessful, please contact customer service.
 FAILEDOPERATION_SUBMITASYNCTASKERROR = 'FailedOperation.SubmitAsyncTaskError'
 
+# This type of operations cannot be performed.
+FAILEDOPERATION_TYPEINCONFLICT = 'FailedOperation.TypeInConflict'
+
 # An internal error occurred.
 INTERNALERROR = 'InternalError'
 
 # An error occurred while querying async tasks.
 INTERNALERROR_ASYNCREQUESTERROR = 'InternalError.AsyncRequestError'
 
+# An error occurred in the internal service of the audit service.
+INTERNALERROR_AUDITERROR = 'InternalError.AuditError'
+
+# Internal exception of the audit service.
+INTERNALERROR_AUDITOSSLOGICERROR = 'InternalError.AuditOssLogicError'
+
 # Authentication failed.
 INTERNALERROR_AUTHERROR = 'InternalError.AuthError'
 
@@ -164,6 +176,12 @@ INTERNALERROR_RESOURCENOTUNIQUE = 'InternalError.ResourceNotUnique'
 # Security group error
 INTERNALERROR_SECURITYGROUPERROR = 'InternalError.SecurityGroupError'
 
+# Internal error of the system.
+INTERNALERROR_SERVERERROR = 'InternalError.ServerError'
+
+# An exception occurred in the internal service.
+INTERNALERROR_SERVICEERROR = 'InternalError.ServiceError'
+
 # Failed to modify the tag. Please try again later.
 INTERNALERROR_TAGERROR = 'InternalError.TagError'
 
@@ -278,6 +296,9 @@ INVALIDPARAMETERVALUE_VERIFYACCOUNTPASSWORDERROR = 'InvalidParameterValue.Verify
 # The account does not have the GRANT permission.
 INVALIDPARAMETERVALUE_VERIFYACCOUNTPRIVERROR = 'InvalidParameterValue.VerifyAccountPrivError'
 
+# The quota limit has been reached.
+LIMITEXCEEDED = 'LimitExceeded'
+
 # Account-related parameters are missing.
 MISSINGPARAMETER_ACCOUNTMISSINGPARAMETERERROR = 'MissingParameter.AccountMissingParameterError'
 
@@ -293,6 +314,27 @@ OPERATIONDENIED_ACTIONINPROCESS = 'OperationDenied.ActionInProcess'
 # Unsupported operation.
 OPERATIONDENIED_ACTIONNOTSUPPORT = 'OperationDenied.ActionNotSupport'
 
+# The audit policies conflict.
+OPERATIONDENIED_AUDITPOLICYCONFLICTERROR = 'OperationDenied.AuditPolicyConflictError'
+
+# The audit policy already exists.
+OPERATIONDENIED_AUDITPOLICYEXISTERROR = 'OperationDenied.AuditPolicyExistError'
+
+# The audit rule has been associated.
+OPERATIONDENIED_AUDITRULEHASBIND = 'OperationDenied.AuditRuleHasBind'
+
+# The audit rule does not exist.
+OPERATIONDENIED_AUDITRULENOTEXISTERROR = 'OperationDenied.AuditRuleNotExistError'
+
+# Exceptional audit status.
+OPERATIONDENIED_AUDITSTATUSERROR = 'OperationDenied.AuditStatusError'
+
+# The audit tasks conflict.
+OPERATIONDENIED_AUDITTASKCONFLICTERROR = 'OperationDenied.AuditTaskConflictError'
+
+# You have enabled the compliance audit feature of DBbrain, so you cannot enable the rule-based audit.
+OPERATIONDENIED_DBBRAINPOLICYCONFLICT = 'OperationDenied.DBBrainPolicyConflict'
+
 # The operation is not allowed during the delayed replication.
 OPERATIONDENIED_DELAYREPLICATIONRUNNING = 'OperationDenied.DelayReplicationRunning'
 
@@ -332,6 +374,9 @@ OPERATIONDENIED_SUBACCOUNTOPERATIONDENIED = 'OperationDenied.SubAccountOperation
 # This instance is not refundable.
 OPERATIONDENIED_UNSUPPORTREFUNDERROR = 'OperationDenied.UnSupportRefundError'
 
+# The audit feature cannot be enabled.
+OPERATIONDENIED_UNSUPPORTOPENAUDITERROR = 'OperationDenied.UnsupportOpenAuditError'
+
 # This account is not authorized to access the requested resource.
 OPERATIONDENIED_USERHASNOSTRATEGY = 'OperationDenied.UserHasNoStrategy'
 
@@ -344,14 +389,29 @@ OPERATIONDENIED_WRONGSTATUS = 'OperationDenied.WrongStatus'
 # Limit exceeded.
 OVERQUOTA = 'OverQuota'
 
+# The resource is occupied.
+RESOURCEINUSE = 'ResourceInUse'
+
+# Insufficient resource.
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
+# The resource does not exist.
+RESOURCENOTFOUND = 'ResourceNotFound'
+
 # The instance cannot be found. Please check whether your instance status is normal.
 RESOURCENOTFOUND_CDBINSTANCENOTFOUNDERROR = 'ResourceNotFound.CdbInstanceNotFoundError'
 
 # The instance does not exist.
 RESOURCENOTFOUND_INSTANCENOTFUNDERROR = 'ResourceNotFound.InstanceNotFundError'
 
+# The resource is unavailable.
+RESOURCEUNAVAILABLE = 'ResourceUnavailable'
+
 # Verification failed. Insufficient permissions.
 UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES = 'UnauthorizedOperation.NotEnoughPrivileges'
 
+# Unsupported operation.
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
 # Unsupported permission.
 UNSUPPORTEDOPERATION_PRIVILEGESUNSUPPORTEDERROR = 'UnsupportedOperation.PrivilegesUnsupportedError'
