@@ -1597,7 +1597,7 @@ class ClsClient(AbstractClient):
     def UploadLog(self, request, body):
         """## Feature Description
 
-        This API is used to write a log to the specified log topic.
+        This API is used to write logs to a specified log topic.
 
         CLS provides the following two modes:
 
@@ -1607,72 +1607,57 @@ class ClsClient(AbstractClient):
 
         #### Hash routing mode
 
-        In this mode, data will be written to a target partition that meets the range requirements based on the hash value (X-CLS-HashKey) carried by data. For example, a log source can be bound to a topic partition through `hashkey`, strictly guaranteeing the sequence of the data written to and consumed in this partition.
+        In this mode, data will be written to a target partition that meets the range requirements based on the hash value (`X-CLS-HashKey`) carried by data. For example, a log source can be bound to a topic partition through `HashKey`, strictly guaranteeing the sequence of the data written to and consumed in this partition.
 
         In addition, CLS allows you to upload logs in the following two modes:
 
 
-        ## Request
+        #### Input parameters (pb binary streams in `body`)
 
-        #### Request header parameters
-
-        The `X-CLS-HashKey` request header indicates that logs are written to the CLS topic partitions with a range corresponding to the hashkey route, strictly guaranteeing the write sequence of logs to each topic partition for sequential consumption.
-
-        | Field | Type | Location | Required | Description |
-        | ------------------ | ------ | ------ | -------- | ------------------------------------------------------------ |
-        | X-CLS-HashKey | string | header | No       | Logs are written to the corresponding topic partition according to `hashkey` |
-        | X-CLS-TopicId      | String | header | Yes       | Topic ID                                                       |                                                 |
-        | Content-Type | String | header | Yes | Protocol type of the request parameter. Currently, only the PB protocol is supported. Please enter "application/octet-stream". |
-        | X-TC-Action | String |	header | Yes | Common parameter. The value used for this API: UploadLog.
-        | X-TC-Region | String | header | Yes	  | Common parameter. This parameter is not required for this API.
-        | X-TC-Version | String | header | Yes | Common parameter. The value used for this API: 2020-10-16.
-
-        #### Input parameters (PB protocol)
-
-        | Field | Type | Location | Required | Description |
+        | Parameter | Type | Location | Required | Description |
         | ------------ | ------- | ---- | ---- | ------------------------------------------------------------ |
-        | logGroupList | message | pb    | Yes   | The logGroup list, which describes the encapsulated log groups. No more than five `logGroup` values are recommended.                     |
+        | logGroupList | message | pb    | Yes   | The `logGroup` list, which describes the encapsulated log groups. We recommend you enter up to 5 `logGroup` values.                     |
 
         `LogGroup` description:
 
-        | Field | Required | Description |
+        | Parameter     | Required | Description                                                         |
         | ----------- | -------- | ------------------------------------------------------------ |
         | logs        | Yes       | Log array consisting of multiple `Log` values. The `Log` indicates a log, and a `LogGroup` can contain up to 10,000 `Log` values. |
-        | contextFlow | No       | Unique LogGroup ID, which should be passed in if the context feature needs to be used. Format: "{context ID}-{LogGroupID}". <br>Context ID: uniquely identifies the context (a series of log files that are continuously scrolling or a series of logs that need to be sequenced), which is a 64-bit integer hex string. <br>LogGroupID: a 64-bit integer hex string that continuously increases, such as "102700A66102516A-59F59".                        |
+        | contextFlow | No       | Unique `LogGroup` ID, which should be passed in if the context feature needs to be used. Format: "{context ID}-{LogGroupID}". <br>Context ID: uniquely identifies the context (a series of log files that are continuously scrolling or a series of logs that need to be sequenced), which is a 64-bit integer hex string. <br>LogGroupID: a 64-bit integer hex string that continuously increases, such as `102700A66102516A-59F59`.                        |
         | filename    | No       | Log filename                                                   |
-        | source      | No       | Log source, which is generally the server IP                           |
-        | logTags     | No       | Tag list of the log                                               |
+        | source      | No       | Log source, which is generally the machine IP                           |
+        | logTags     | No       | Tag list of logs                                               |
 
         `Log` description:
 
-        | Field | Required | Description |
+        | Parameter | Required | Description |
         | -------- | -------- | ------------------------------------------------------------ |
-        | time | Yes | UNIX timestamp of log time in seconds or milliseconds (recommended) |
-        | contents | No | Log content in `key-value` format. A log can contain multiple `key-value` pairs. |
+        | time | Yes | Unix timestamp of log time in seconds or milliseconds (recommended) |
+        | contents | No | Log content in key-value format. A log can contain multiple key-value pairs. |
 
         `Content` description:
 
-        | Field | Required | Description |
+        | Parameter | Required | Description |
         | ------ | -------- | ------------------------------------------------------------ |
         | key    | Yes       | Key of a field group in one log, which cannot start with `_`.                 |
-        | value  | Yes       | Value of a field group, which cannot exceed 1 MB in one log. The total value cannot exceed 5 MB in `LogGroup`. |
+        | value  | Yes       | Value of a field group. The `value` of one log cannot exceed 1 MB and the total `value` in `LogGroup` cannot exceed 5 MB. |
 
         `LogTag` description:
 
-        | Field | Required | Description |
+        | Parameter     | Required | Description                                                         |
         | ------ | -------- | -------------------------------- |
-        | key    | Yes       | Key of a custom tag                 |
+        | key    | Yes       | Key of a custom tag             |
         | value  | Yes       | Value corresponding to the custom tag key |
 
-        ## PB Compilation Sample
+        ## pb Compilation Sample
 
-        This sample describes how to use the protoc compiler to compile the PB description file into a log upload API in C++.
+        This sample describes how to use the protoc compiler to compile the pb description file into a log upload API in C++.
 
         > ?Currently, protoc supports compilation in multiple programming languages such as Java, C++, and Python. For more information, please see [protoc](https://github.com/protocolbuffers/protobuf).
 
-        #### 1. Install Protocol Buffer
+        #### 1. Install Protocol Buffers
 
-        Download [Protocol Buffer](https://main.qcloudimg.com/raw/d7810aaf8b3073fbbc9d4049c21532aa/protobuf-2.6.1.tar.gz), decompress the package, and install the tool. The version used in the sample is protobuf 2.6.1 running on CentOS 7.3. Run the following command to decompress the `protobuf-2.6.1.tar.gz` package to the `/usr/local` directory and enter the directory:
+        Download [Protocol Buffers](https://main.qcloudimg.com/raw/d7810aaf8b3073fbbc9d4049c21532aa/protobuf-2.6.1.tar.gz), decompress the package, and install the tool. The version used in the sample is protobuf 2.6.1 running on CentOS 7.3. Run the following command to decompress the `protobuf-2.6.1.tar.gz` package to the `/usr/local` directory and enter the directory:
 
         ```
         tar -zxvf protobuf-2.6.1.tar.gz -C /usr/local/ && cd /usr/local/protobuf-2.6.1
@@ -1693,15 +1678,15 @@ class ClsClient(AbstractClient):
         liprotoc 2.6.1
         ```
 
-        #### 2. Create a PB description file
+        #### 2. Create a pb description file
 
-        A PB description file is an agreed-on data exchange format for communication. To upload logs, please compile the specified protocol format to an API in the target programming language and add the API to the project code. For more information, please see [protoc](https://github.com/protocolbuffers/protobuf).
+        A pb description file is an agreed-on data interchange format for communication. To upload logs, please compile the specified protocol format to an API in the target programming language and add the API to the project code. For more information, please see [protoc](https://github.com/protocolbuffers/protobuf).
 
-        Create a PB message description file `cls.proto` based on the PB data format content specified by CLS.
+        Create a pb message description file `cls.proto` based on the pb data format content specified by CLS.
 
-        > !The PB description file content cannot be modified, and the filename must end with `.proto`.
+        > !The pb description file content cannot be modified, and the filename must end with `.proto`.
 
-        The content of `cls.proto` (PB description file) is as follows:
+        The content of `cls.proto` (pb description file) is as follows:
 
         ```
         package cls;
@@ -1714,7 +1699,7 @@ class ClsClient(AbstractClient):
                 required string value = 2; // Value of each field group
             }
             required int64   time     = 1; // Unix timestamp
-            repeated Content contents = 2; // Multiple `key-value` pairs in one log
+            repeated Content contents = 2; // Multiple key-value pairs in one log
         }
 
         message LogTag
@@ -1728,7 +1713,7 @@ class ClsClient(AbstractClient):
             repeated Log    logs        = 1; // Log array consisting of multiple logs
             optional string contextFlow = 2; // This parameter does not take effect currently
             optional string filename    = 3; // Log filename
-            optional string source      = 4; // Log source, which is generally the server IP
+            optional string source      = 4; // Log source, which is generally the machine IP
             repeated LogTag logTags     = 5;
         }
 
@@ -1746,9 +1731,9 @@ class ClsClient(AbstractClient):
         protoc --cpp_out=./ ./cls.proto
         ```
 
-        > ?`--cpp_out=./` indicates that the file will be compiled in cpp format and output to the current directory. `./cls.proto` indicates the `cls.proto` description file in the current directory.
+        > ?`--cpp_out=./ ` indicates that the file will be compiled in cpp format and output to the current directory. `./cls.proto` indicates the `cls.proto` description file in the current directory.
 
-        After the compilation succeeds, the code file in the corresponding programming language will be generated. This sample generates the `cls.pb.h` header file and [cls.pb.cc](http://cls.pb.cc) code implementation file as shown below:
+        After the compilation succeeds, the code file in the corresponding programming language will be generated. This sample generates the `cls.pb.h` header file and `cls.pb.cc` code implementation file as shown below:
 
         ```
         [root@VM_0_8_centos protobuf-2.6.1]# protoc --cpp_out=./ ./cls.proto
@@ -1756,9 +1741,9 @@ class ClsClient(AbstractClient):
         cls.pb.cc cls.pb.h cls.proto
         ```
 
-        #### 4. Call
+        #### 4. Call the API
 
-        Import the generated `cls.pb.h` header file into the code and call the API for data format encapsulation.
+        Import the generated `cls.pb.h` header file into the code and call the API for data encapsulation.
 
         :param request: Request instance for UploadLog.
         :type request: :class:`tencentcloud.cls.v20201016.models.UploadLogRequest`
