@@ -1430,7 +1430,9 @@ class LighthouseClient(AbstractClient):
         """This API is used to reset the password of the instance OS to a user-specified password.
         * You can only use this API to modify the password of the admin account. The name of the admin account varies by OS (on Windows, it is `Administrator`; on Ubuntu, it is `ubuntu`; on other systems, it is `root`).
         * Batch operations are supported. You can reset the passwords of multiple instances to the same one. The maximum number of instances in each request is 100.
+        * It’s recommended to shut down the instance first and then reset the password. If the instance is running, this API will try to shut it down normally. If the attempt fails, it will force to instance to shut down.
         * This API is async. After the request is sent successfully, a `RequestId` will be returned. At this time, the operation is not completed immediately. The result of the instance operation can be queried by calling the `DescribeInstances` API. If the latest operation status (LatestOperationState) of the instance is `SUCCESS`, the operation is successful.
+        Note: Just like powering off a physical PC, a forced shutdown may cause data loss or the corruption of file system.
 
         :param request: Request instance for ResetInstancesPassword.
         :type request: :class:`tencentcloud.lighthouse.v20200324.models.ResetInstancesPasswordRequest`
@@ -1523,10 +1525,10 @@ class LighthouseClient(AbstractClient):
 
 
     def TerminateInstances(self, request):
-        """This API is used to return instances.
+        """This API is used to terminate one or more instances.
 
         * Instances in `SHUTDOWN` status can be terminated through this API and cannot be recovered.
-        * Batch operations are supported. The maximum number of instances in each request is 100.
+        * Batch operations are supported. The allowed maximum number of instances in each request is 100.
         * This API is async. After the request is sent successfully, a `RequestId` will be returned. At this time, the operation is not completed immediately. The result of the instance operation can be queried by calling the `DescribeInstances` API. If the latest operation status (LatestOperationState) of the instance is `SUCCESS`, the operation is successful.
 
         :param request: Request instance for TerminateInstances.
