@@ -194,6 +194,34 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePrivateDNSAccountList(self, request):
+        """This API is used to get the list of Private DNS accounts.
+
+        :param request: Request instance for DescribePrivateDNSAccountList.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribePrivateDNSAccountListRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DescribePrivateDNSAccountListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePrivateDNSAccountList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePrivateDNSAccountListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribePrivateZone(self, request):
         """This API is used to get the private domain information.
 
